@@ -21,19 +21,36 @@ import os
 import sys
 
 import click
-from click_shell import shell
+
 from incenp.pebble import __version__
 from incenp.pebble.cache import Vault
 from incenp.pebble.editor import edit_credential
 from incenp.pebble.server import Server
 from incenp.pebble.util import SecretCache, Error
 
+# Click-shell is broken with Click >= 8.0.0; if we can't import it,
+# then we fall back to standard click, without the shell feature.
+try:
+    from click_shell import shell
+    has_shell = True
+
+    def group():
+        return shell(prompt='pbl> ', context_settings=CONTEXT_SETTINGS)
+
+except ImportError:
+    has_shell = False
+
+    def group():
+        return click.group(invoke_without_command=True,
+                           context_settings=CONTEXT_SETTINGS)
+
 try:
     import keyring
     use_keyring = True
 except:
     use_keyring = False
 
+CONTEXT_SETTINGS = {'help_option_names': ['-h', '--help']}
 prog_name = "pbl"
 prog_notice = f"""\
 {prog_name} (Pebble {__version__})
@@ -205,8 +222,7 @@ class PebbleContext(object):
             return parse_duration(max_age_s)
 
 
-@shell(prompt="pbl> ",
-       context_settings={'help_option_names': ['-h', '--help']})
+@group()
 @click.option('--config', '-c', type=click.Path(exists=False),
               default='{}/config'.format(click.get_app_dir('pebble')),
               help="Path to an alternative configuration file.")
@@ -234,6 +250,9 @@ def pebble(ctx, config, section, refresh, no_refresh):
     if not pbl.has_config:
         ctx.invoke(conf)
 
+    if ctx.invoked_subcommand is None and not has_shell:
+        ctx.invoke(list_credentials)
+
     ctx.call_on_close(pbl.close)
 
 
